@@ -19,6 +19,7 @@ from spectrafit.report import PrintingStatus
 from spectrafit.tools import PostProcessing
 from spectrafit.tools import PreProcessing
 from spectrafit.tools import SaveResult
+from spectrafit.tools import check_keywords_consistency
 from spectrafit.tools import load_data
 from spectrafit.tools import read_input_file
 
@@ -87,17 +88,18 @@ def get_args() -> Dict[str, Any]:
         "--shift",
         type=float,
         default=None,
-        help="Constant applied energy shift; default to 0.0.",
+        help="Constant applied energy shift",
     )
     parser.add_argument(
         "-c",
         "--column",
         nargs=2,
-        type=int,
         default=[0, 1],
         help=(
-            "Selected columns for the energy- and intensity-values; default to 0 for"
-            " energy (x-axis) and 1 for intensity (y-axis)."
+            "Selected columns for the energy- and intensity-values; default to '0' for"
+            " energy (x-axis) and '1' for intensity (y-axis). In case of working with"
+            " header, the column should be set to the column names as 'str'; default"
+            " to 0 and 1."
         ),
     )
     parser.add_argument(
@@ -141,7 +143,7 @@ def get_args() -> Dict[str, Any]:
         "--autopeak",
         help=(
             "Auto detection of peaks in the spectra based on `SciPy`. The position, "
-            "height, and width are used as estimation for the `Gaussian` models."
+            "height, and width are used as estimation for the `Gaussian` models. "
             "The default option is 'False' for manual peak definition."
         ),
         action="store_true",
@@ -165,9 +167,14 @@ def get_args() -> Dict[str, Any]:
     parser.add_argument(
         "-vb",
         "--verbose",
-        help="Display the initial configuration parameters as a dictionary.",
-        action="store_true",
-        default=False,
+        help=(
+            "Display the initial configuration parameters and fit results, as a table "
+            "'1', as a dictionary '2', or not in the terminal '0'. The default option "
+            "is set to 1 for table `printout`."
+        ),
+        type=int,
+        default=1,
+        choices=[0, 1, 2],
     )
     return vars(parser.parse_args())
 
@@ -220,6 +227,7 @@ def extracted_from_command_line_runner() -> Dict[str, Any]:
     """
     result = get_args()
     _args = read_input_file(result["input"])
+    check_keywords_consistency(check_args=_args["settings"], ref_args=result)
     if "settings" in _args.keys():
         for key in _args["settings"].keys():
             result[key] = _args["settings"][key]
@@ -229,11 +237,11 @@ def extracted_from_command_line_runner() -> Dict[str, Any]:
         if "minimizer" in _args["fitting"]["parameters"].keys():
             result["minimizer"] = _args["fitting"]["parameters"]["minimizer"]
         else:
-            raise SystemExit("Missing 'minimizer' in 'parameters'!")
+            raise KeyError("Missing 'minimizer' in 'parameters'!")
         if "optimizer" in _args["fitting"]["parameters"].keys():
             result["optimizer"] = _args["fitting"]["parameters"]["optimizer"]
         else:
-            raise SystemExit("Missing key 'optimizer' in 'parameters'!")
+            raise KeyError("Missing key 'optimizer' in 'parameters'!")
         if "report" in _args["fitting"]["parameters"].keys():
             result["report"] = _args["fitting"]["parameters"]["report"]
         else:
